@@ -44,6 +44,8 @@ class Blueprint:
         except Exception as e:
             raise DatabaseError(f"Failed to connect to SQLite DB at '{db_path}': {e}")
 
+
+    
     def _initialize_table(self) -> None:
         """
         Create tasks table if not exists, according to the defined schema.
@@ -105,8 +107,6 @@ class Blueprint:
         row = self._execute_query(sql, (task_id,), fetch='one')
         if not row:
             return None
-        cols = [col[0] for col in self.conn.cursor().description] if False else []
-        # Actually get column names via PRAGMA
         cols = [info[1] for info in self._execute_query("PRAGMA table_info(tasks)", fetch='all')]
         return dict(zip(cols, row))
 
@@ -215,6 +215,7 @@ class Blueprint:
         current = pd.read_sql_query("SELECT * FROM tasks", self.conn, index_col='task_id')
         incoming = df.set_index('task_id')
         updates = []  # list of (task_id, {col: new_val, ...})
+        
         for tid, row in incoming.iterrows():
             if tid not in current.index:
                 continue  # skip new tasks
@@ -223,12 +224,32 @@ class Blueprint:
                 if col in incoming.columns:
                     new_val = row[col]
                     old_val = current.at[tid, col]
+                    
+                    # Special handling for dependencies column
+                    if col == 'dependencies' and pd.notna(new_val):
+                        # Clean up dependencies: convert floats to ints
+                        if isinstance(new_val, (int, float)):
+                            new_val = str(int(new_val))
+                        elif isinstance(new_val, str):
+                            # Handle comma-separated dependencies
+                            deps = []
+                            for dep in new_val.split(','):
+                                dep = dep.strip()
+                                if dep:
+                                    try:
+                                        deps.append(str(int(float(dep))))
+                                    except (ValueError, TypeError):
+                                        print(f"[weaver] Warning: Invalid dependency '{dep}' in task {tid}")
+                            new_val = ','.join(deps) if deps else ''
+                    
                     if pd.notna(new_val) and new_val != old_val:
                         changes[col] = new_val
             if changes:
                 updates.append((tid, changes))
+                
         if not updates:
             return
+            
         # Apply in a single transaction
         try:
             self._execute_query("BEGIN TRANSACTION")
@@ -242,4 +263,4 @@ class Blueprint:
         except Exception as e:
             self._execute_query("ROLLBACK")
             self.conn.commit()
-            raise DatabaseError(f"Failed to update from DataFrame: {e}")
+            raise DatabaseError(f"Failed to update from DataFrame: {e}")
\ No newline at end of file
